Improve this Doc

# $interpolate

Here are the list of errors in the $interpolate namespace.

Name | Description
--- | ---
badexpr | Expecting end operator
dupvalue | Duplicate choice in plural/select
interr | Interpolation Error
logicbug | Bug in ngMessageFormat module
nochgmustache | Redefinition of start/endSymbol incompatible with MessageFormat extensions
noconcat | Multiple Expressions
reqarg | Missing required argument for MessageFormat
reqcomma | Missing comma following MessageFormat plural/select keyword
reqendbrace | Unterminated message for plural/select value
reqendinterp | Unterminated interpolation
reqopenbrace | An opening brace was expected but not found
reqother | Required choice "other" for select/plural in MessageFormat
unknarg | Unrecognized MessageFormat extension
unsafe | MessageFormat extensions not allowed in secure context
untermstr | Unterminated string literal
wantstring | Expected the beginning of a string